/*
 * Copyright (c) 2015, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/** ============================================================================
 *  @file       AT45DBFatFs.h
 *
 *  @brief      AT45DB Flash Driver for FatFS
 */

#ifndef AT45DBFATFS_H_
#define AT45DBFATFS_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sysbios/fatfs/ff.h>
#include <ti/sysbios/fatfs/diskio.h>
#include "AT45DB.h"

#define AT45DBFatFs_FLASH_SECTOR_SIZE           512
#define AT45DBFatFs_DRIVE_NOT_MOUNTED           ~0

/*!
 *  @brief AT45DBFatFs Parameters
 *
 *  This is a place-holder structure now since there are no parameters
 *  for the open calls.
 *
 *  @sa         AT45DBFatFs_Params_init()
 */
 typedef struct AT45DBFatFs_Params {
    uint8_t dummy;
} AT45DBFatFs_Params;


/*!
 *  @brief AT45DBFatFs Object
 *
 *  The application should never directly access the fields in the structure.
 */
typedef struct AT45DBFatFs_Object {
    AT45DB_Object at45dbObj;
    UInt          driveNumber;
    FATFS         fileSystem;
    DSTATUS       diskState;     /*!< Disk status */
}AT45DBFatFs_Object;

/*!
 *  @brief AT45DBFatFs Handle
 *
 *  Used to identify a AT45DBFatFs device in the APIs
 */
typedef AT45DBFatFs_Object *AT45DBFatFs_Handle;

/*!
 *  @brief  Function to close a AT45DBFatFS object
 */
void AT45DBFatFs_close(AT45DBFatFs_Handle handle);

/*!
 *  @brief  Function to initialize the AT45DBFatFS module
 */
void AT45DBFatFs_init();

/*!
 *  @brief  Function to open a  AT45DBFatFS object
 */
AT45DBFatFs_Handle AT45DBFatFs_open(SPI_Handle spiHandle,
                                    unsigned int gpioCSIndex, 
                                    AT45DBFatFs_Params *params, 
                                    UInt drv);

/*!
 *  @brief  Function to initialize a AT45DBFatFS parameter structure
 */
void AT45DBFatFs_Params_init(AT45DBFatFs_Params *params);

#ifdef __cplusplus
extern "C" {
#endif

#endif /* AT45DBFATFS_H_ */
